@@ -26,9 +26,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-fno-strict-overflow -Wsign-compare '
-           '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
-           '-fcf-protection -fexceptions -fcf-protection -fexceptions '
-           '-fcf-protection',
+           '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fcf-protection '
+           '-fexceptions -fcf-protection -fexceptions -fcf-protection '
+           '-fexceptions',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CODECS_COMMON_HEADERS': '/builddir/build/BUILD/Python-3.12.2/Modules/cjkcodecs/multibytecodec.h '
@@ -36,7 +36,7 @@ build_time_vars = {'ABIFLAGS': '',
  'COMPILEALL_OPTS': '-j0',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-fexceptions -fcf-protection',
+ 'CONFIGURE_CFLAGS': '-fcf-protection -fexceptions',
  'CONFIGURE_CFLAGS_NODIST': '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
                             '-grecord-gcc-switches -pipe -Wall '
                             '-Werror=format-security '
@@ -92,7 +92,7 @@ build_time_vars = {'ABIFLAGS': '',
                 "'build_alias=x86_64-redhat-linux-gnu' "
                 "'host_alias=x86_64-redhat-linux-gnu' "
                 "'PKG_CONFIG_PATH=:/usr/lib64/pkgconfig:/usr/share/pkgconfig' "
-                "'CC=gcc' 'CFLAGS=-fexceptions -fcf-protection  ' 'LDFLAGS= ' "
+                "'CC=gcc' 'CFLAGS=-fcf-protection -fexceptions  ' 'LDFLAGS= ' "
                 "'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
@@ -673,9 +673,9 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDIR': '/usr/lib64',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
  'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare '
-                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
-                    '-fcf-protection -fexceptions -fcf-protection -fexceptions '
-                    '-fcf-protection -O2 -flto=auto -ffat-lto-objects '
+                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fcf-protection '
+                    '-fexceptions -fcf-protection -fexceptions -fcf-protection '
+                    '-fexceptions -O2 -flto=auto -ffat-lto-objects '
                     '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                     '-Werror=format-security '
                     '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
@@ -710,8 +710,8 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBHACL_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.2/Modules/_hacl/include '
                    '-D_BSD_SOURCE -D_DEFAULT_SOURCE -fno-strict-overflow '
                    '-Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
-                   '-fexceptions -fcf-protection -fexceptions -fcf-protection '
-                   '-fexceptions -fcf-protection -O2 -flto=auto '
+                   '-fcf-protection -fexceptions -fcf-protection -fexceptions '
+                   '-fcf-protection -fexceptions -O2 -flto=auto '
                    '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
                    '-pipe -Wall -Werror=format-security '
                    '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
@@ -749,9 +749,9 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 '
                     '-fno-strict-overflow -Wsign-compare '
-                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
-                    '-fcf-protection -fexceptions -fcf-protection -fexceptions '
-                    '-fcf-protection -O2 -flto=auto -ffat-lto-objects '
+                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fcf-protection '
+                    '-fexceptions -fcf-protection -fexceptions -fcf-protection '
+                    '-fexceptions -O2 -flto=auto -ffat-lto-objects '
                     '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                     '-Werror=format-security '
                     '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
@@ -1121,7 +1121,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions -fcf-protection',
+ 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fcf-protection -fexceptions',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
  'PACKAGE_STRING': 0,
@@ -1157,8 +1157,8 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha2,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
                              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
-                             '-fexceptions -fcf-protection -fexceptions '
-                             '-fcf-protection -fexceptions -fcf-protection -O2 '
+                             '-fcf-protection -fexceptions -fcf-protection '
+                             '-fexceptions -fcf-protection -fexceptions -O2 '
                              '-flto=auto -ffat-lto-objects -fexceptions -g '
                              '-grecord-gcc-switches -pipe -Wall '
                              '-Werror=format-security '
@@ -1197,9 +1197,9 @@ build_time_vars = {'ABIFLAGS': '',
                              '-I/builddir/build/BUILD/Python-3.12.2/Include '
                              '-fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare '
-              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
-              '-fcf-protection -fexceptions -fcf-protection -fexceptions '
-              '-fcf-protection',
+              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fcf-protection '
+              '-fexceptions -fcf-protection -fexceptions -fcf-protection '
+              '-fexceptions',
  'PY_CFLAGS_NODIST': '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
                      '-grecord-gcc-switches -pipe -Wall '
                      '-Werror=format-security '
@@ -1231,10 +1231,10 @@ build_time_vars = {'ABIFLAGS': '',
                      '-I/builddir/build/BUILD/Python-3.12.2/Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
-                   '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
-                   '-fcf-protection -fexceptions -fcf-protection -fexceptions '
-                   '-fcf-protection -O2 -flto=auto -ffat-lto-objects '
-                   '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
+                   '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fcf-protection '
+                   '-fexceptions -fcf-protection -fexceptions -fcf-protection '
+                   '-fexceptions -O2 -flto=auto -ffat-lto-objects -fexceptions '
+                   '-g -grecord-gcc-switches -pipe -Wall '
                    '-Werror=format-security '
                    '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                    '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -1311,10 +1311,10 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHERS': 2,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
-                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
+                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
                         '-fcf-protection -fexceptions -fcf-protection '
-                        '-fexceptions -fcf-protection -O2 -flto=auto '
-                        '-ffat-lto-objects -fexceptions -g '
+                        '-fexceptions -fcf-protection -fexceptions -O2 '
+                        '-flto=auto -ffat-lto-objects -fexceptions -g '
                         '-grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security '
                         '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
